.. yeadon documentation master file, created by
   sphinx-quickstart on Thu Jun 30 16:11:26 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to yeadon's documentation!
==================================

Contents of this documentation:

.. toctree::
   :maxdepth: 1

   overview.rst
   modules.rst
   usage.rst
   measurements.rst
   configuration.rst
   releasenotes.rst

Information about this package can also be obtained from within python with
commands such as help(yeadon) and help(yeadon.human) (assuming the user has
imported yeadon) or from the README.txt file in the root yeadon/ directory, or
from the sample text input files in the root yeadon/ directory.

The README.txt contains installation instructions.

This package was developed during the Summer of 2011 at the University of
California, Davis, to aid with the bicycle research of Jason Moore and Dale
Luke Peterson in the Sports Biomechanics Lab of Professor Mont Hubbard. Learn
more about the Sports Biomechanics Lab at `biosport.ucdavis.edu
<http://biosport.ucdavis.edu>`_.

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
